package com.ynet.life.action;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.life.base.LifeDBAccess;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.loaf.LoafConstants;
import com.ynet.life.loaf.jdbc.LoafQueryFactory;
import com.ynet.life.loaf.jdbc.LoafQueryInterface;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;
import java.util.regex.Matcher;

/* loaded from: com_ynet_life_action.jar:com/ynet/life/action/SQLAccessAction.class */
public class SQLAccessAction extends LifeJDBCAction {
    private String querySql;
    private List inputFields;

    public String execute(Context context) throws GENEException {
        try {
            List input = getInputList(context);
            try {
                try {
                    LoafQueryInterface query = LoafQueryFactory.getNewQuery("", "", this.querySql);
                    Connection connection = LifeDBAccess.getConnection(getDataSource());
                    PreparedStatement ps = query.getQueryStatement(connection, input);
                    int changeCount = ps.executeUpdate();
                    Trace.logDebug("LOAF", "SQL执行影响的记录条数--->".concat(String.valueOf(changeCount)));
                    LifeDBAccess.cleanResources(ps);
                    LifeDBAccess.releaseConnection(getDataSource(), connection);
                    return String.valueOf(changeCount);
                } catch (Throwable th) {
                    LifeDBAccess.cleanResources((PreparedStatement) null);
                    throw th;
                }
            } catch (SQLException se) {
                TranFailException tfe = new TranFailException(se);
                Trace.logError("LOAF", se.getMessage(), se);
                context.put("GENEException", tfe);
                throw tfe;
            }
        } catch (Throwable th2) {
            LifeDBAccess.releaseConnection(getDataSource(), (Connection) null);
            throw th2;
        }
    }

    private List getInputList(Context context) throws GENEException {
        List result = new ArrayList();
        for (String fieldName : this.inputFields) {
            try {
                String inputValue = context.getDataValue(fieldName) == null ? null : context.getDataValue(fieldName).toString();
                result.add(inputValue);
            } catch (GENEException empe) {
                Trace.logError("LOAF", "未定义的输入参数", empe);
                throw empe;
            }
        }
        return result;
    }

    public void setQuerySql(String querySql) {
        this.querySql = LoafConstants.PATTERN_INPUT_FIELD.matcher(querySql).replaceAll("?");
        List result = new LinkedList();
        Matcher matcher = LoafConstants.PATTERN_INPUT_FIELD.matcher(querySql);
        while (matcher.find()) {
            String fieldName = matcher.group().substring(1);
            result.add(fieldName);
        }
        this.inputFields = result;
    }
}
